.. -*- mode: rst -*-

|Travis|_ |Coveralls|_

.. |Travis| image:: https://api.travis-ci.org/hiclib/iced.png?branch=master
.. _Travis: https://travis-ci.org/hiclib/iced

.. |Coveralls| image::
   https://coveralls.io/repos/github/hiclib/iced/badge.svg?branch=master
.. _Coveralls: https://coveralls.io/r/hiclib/iced?branch=master


iced
====

The python module iced implements the ICE normalization of hic data


Depends on

python >= 2.6
numpy >= 1.9
scipy >= 0.14
sklearn
pandas
